#!/bin/bash

# cd to parent directory of this script
bin=$( dirname "$0" )
cd "$bin/.."

# insert tag text
insert () {
  perl -p -e "s|<-$1->|$2|"
}

# output title
output () {
  markdown | cat head - foot | insert title "$1"
}

output1 () {
  markdown | cat head1 - foot | insert title "$1"
}

# semester 'S11' 'LinearAlgebra' 'Spring 2011'
semester () {
   echo "#### [$3](../$1/$2)"
   echo
   cd "../$1"
   for file in `ls | grep -v inal` `ls | grep inal`
   do
      echo "* [$file](https://www.math.columbia.edu/~bayer/LinearAlgebra/$1/$file)"
   done
   echo
}

# courses
courses () {
   semester F22 LinearAlgebra 'Fall 2022'
   semester F21 LinearAlgebra 'Fall 2021'
   semester F20 LinearAlgebra 'Fall 2020'
   semester F18 LinearAlgebra 'Fall 2018'
   semester F17 LinearAlgebra 'Fall 2017'
   semester F16 LinearAlgebra 'Fall 2016'
   semester F15 LinearAlgebra 'Fall 2015'
   semester F14 LinearAlgebra 'Fall 2014'
   semester S14 LinearAlgebra 'Spring 2014'
   semester F13 LinearAlgebra 'Fall 2013'
   semester S13 LinearAlgebra 'Spring 2013'
   semester S12 LinearAlgebra 'Spring 2012'
   semester S11 LinearAlgebra 'Spring 2011'
   semester F07 linalg 'Fall 2007'
   semester S07 linalg 'Spring 2007'
   semester F06 linalg 'Fall 2006'
   semester S05 linalg 'Spring 2005'
   semester S04 linalg 'Spring 2004'
   semester S03 linalg 'Spring 2003'
   semester S01 linalg 'Spring 2001'
   semester F00 linalg.html 'Fall 2000'
   semester F99 linalg.html 'Fall 1999'
}

# index.html
cat index.md |\
   insert courses "$(courses)" > computed.md
cat computed.md |\
   output "$(cat title)" > ../index.php

# video
cat video.md |\
	output1 "$(cat title)" > ../Video/index.php

# chalk
cat chalk.md |\
	output1 "$(cat title)" > ../Video/Chalk.php

# source.html
cat source.md |\
   output "$(cat title) (Page Sources)" > ../source.php

# create tarball, update math.columbia.edu, and open page
cd ..
math-tarball.sh
math-update.rb
math-open.sh
